@@ -208,6 +208,16 @@ class TestProcessingPipeline(unittest.TestCase):
         PP.write_file([test_item_ext])
         self.assertEqual(test_item["output"], readf(test_item_ext_gold))
 
+        test_item_no_render = test_item_ext | {
+            "meta": {
+                "no_render": True
+            },
+            "destination": "no_render.txt"
+        }
+
+        PP.write_file([test_item_no_render])
+        self.assertFalse(os.path.exists("no_render.txt"))
+
     def test_load_image(self):
         item = self.item | {
             "origin": "test_load.png"
